@@ -24,6 +24,7 @@ no_pound = False
 no_get = False
 no_validate_ct = False
 verbose = False
+max_crawl = 0
 scanned_urls = []
 internal_urls = []
 skipped_urls = []
@@ -82,6 +83,10 @@ def deep_crawl(depth=2):
             if url not in scanned_urls:
                 scan_url(url)
 
+                # Limit crawl
+                if max_crawl > 0 and len(internal_urls) >= max_crawl:
+                    return
+
 
 def scan_url(url):
     """ Scan a URL """
@@ -224,6 +229,10 @@ def find_urls(soup):
                         continue
 
                     internal_urls = internal_urls + [url]
+
+                    # Limit crawl
+                    if max_crawl > 0 and len(internal_urls) >= max_crawl:
+                        return
             else:  # Different website
                 if url not in external_urls:
                     external_urls = external_urls + [url]
@@ -232,20 +241,22 @@ def find_urls(soup):
 
 
 def main():
-    global base_url, no_pound, no_get, no_validate_ct, verbose
+    global base_url, no_pound, no_get, no_validate_ct, verbose, max_crawl
 
     # Parse arguments
     parser = argparse.ArgumentParser()
     parser.add_argument("-u", "--url", type=str,
                         help="URL to crawl", required=True)
     parser.add_argument("-d", "--depth", type=int,
-                        help="Depth of the crawl", default=2)
+                        help="Depth of the crawl", default=1)
     parser.add_argument("-p", "--no_pound",
                         action='store_true', help="Discard local anchors")
     parser.add_argument("-g", "--no_get", action='store_true',
                         help="Discard GET parameters")
     parser.add_argument("-c", "--no_validate_ct", action='store_true',
                         help="Accept non text/html content types")
+    parser.add_argument("-m", "--max", type=int,
+                        help="Max number of internal URLs to return (allows to limit crawling of a large website)", default=0)
     parser.add_argument("-v", "--verbose", action='store_true',
                         help="Verbose mode")
     args = parser.parse_args()
@@ -256,6 +267,7 @@ def main():
     no_get = args.no_get
     no_validate_ct = args.no_validate_ct
     verbose = args.verbose
+    max_crawl = args.max
 
     deep_crawl(args.depth)
 
